@@ -28,10 +28,10 @@
 extern void setStackTraceHooks();
 #endif
 
-#include <time.h>
 #include <stdio.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <time.h>
 
 #ifdef _MSC_VER
 #ifndef access
@@ -54,23 +54,23 @@ extern void setStackTraceHooks();
 #include <android/log.h>
 #endif /* __ANDROID__ */
 
-typedef struct{
+typedef struct {
 	char *domain;
 	unsigned int logmask;
 #ifdef THREAD_LOG_LEVEL_ENABLED
 	int thread_level_set; /* Set to 1 if a thread specific log level has been set. This enables an optimisation
-				only for the case of an app that never uses per-thread log levels.*/
+	            only for the case of an app that never uses per-thread log levels.*/
 	pthread_key_t thread_level_key; /* The key to access the thread specific level. */
 #endif
-}BctoolboxLogDomain;
+} BctoolboxLogDomain;
 
 #ifdef THREAD_LOG_LEVEL_ENABLED
-static void thread_level_key_destroy(void *ptr){
+static void thread_level_key_destroy(void *ptr) {
 	bctbx_free(ptr);
 }
 #endif
 
-static BctoolboxLogDomain * bctbx_log_domain_new(const char *domain, unsigned int logmask){
+static BctoolboxLogDomain *bctbx_log_domain_new(const char *domain, unsigned int logmask) {
 	BctoolboxLogDomain *ld = bctbx_new0(BctoolboxLogDomain, 1);
 	ld->domain = domain ? bctbx_strdup(domain) : NULL;
 	ld->logmask = logmask;
@@ -81,17 +81,17 @@ static BctoolboxLogDomain * bctbx_log_domain_new(const char *domain, unsigned in
 	return ld;
 }
 
-void bctbx_log_domain_destroy(BctoolboxLogDomain *obj){
+void bctbx_log_domain_destroy(BctoolboxLogDomain *obj) {
 #if THREAD_LOG_LEVEL_ENABLED
 	pthread_key_delete(obj->thread_level_key);
-#endif	
+#endif
 	if (obj->domain) bctbx_free(obj->domain);
 	bctbx_free(obj);
 }
 
 #if THREAD_LOG_LEVEL_ENABLED
-unsigned int bctbx_log_domain_get_thread_log_level_mask(BctoolboxLogDomain *ld){
-	unsigned int *specific = (unsigned int*)pthread_getspecific(ld->thread_level_key);
+unsigned int bctbx_log_domain_get_thread_log_level_mask(BctoolboxLogDomain *ld) {
+	unsigned int *specific = (unsigned int *)pthread_getspecific(ld->thread_level_key);
 	if (!specific) return 0;
 	return *specific;
 }
@@ -106,45 +106,50 @@ typedef struct _bctbx_logger_t {
 	bctbx_mutex_t log_stored_messages_mutex;
 	bctbx_mutex_t domains_mutex;
 	bctbx_mutex_t log_mutex;
-	bctbx_log_handler_t * default_handler;
+	bctbx_log_handler_t *default_handler;
 } bctbx_logger_t;
 
 struct _bctbx_log_handler_t {
 	BctbxLogHandlerFunc func;
 	BctbxLogHandlerDestroyFunc destroy;
 	char *domain; /*domain this log handler is limited to. NULL for all*/
-	void* user_info;
+	void *user_info;
 };
 
 typedef struct _bctbx_file_log_handler_t {
-	char* path;
-	char* name;
+	char *path;
+	char *name;
 	uint64_t max_size;
 	uint64_t size;
-	FILE* file;
+	FILE *file;
 	bool_t reopen_requested;
 } bctbx_file_log_handler_t;
 
+void bctbx_logv_out_cb(void *user_info, const char *domain, BctbxLogLevel lev, const char *fmt, va_list args);
 
-void bctbx_logv_out_cb(void* user_info, const char *domain, BctbxLogLevel lev, const char *fmt, va_list args);
+static char *format_tags(void);
 
-static void wrapper(void* info,const char *domain, BctbxLogLevel lev, const char *fmt, va_list args) {
+static void wrapper(void *info, const char *domain, BctbxLogLevel lev, const char *fmt, va_list args) {
 	BctbxLogFunc func = (BctbxLogFunc)info;
-	if (func) func(domain, lev, fmt,  args);
+	if (func) func(domain, lev, fmt, args);
 }
 
+static void bctbx_handler_uninit(bctbx_log_handler_t *handler);
+static void bctbx_handler_logv_file_uninit(bctbx_log_handler_t *handler);
+static void bctbx_handler_logv_file_destroy(bctbx_log_handler_t *handler);
+
 static bctbx_logger_t main_logger = {0};
 static bctbx_log_handler_t static_handler = {0};
 
 static void initialize_default_handler(void) {
 	main_logger.default_handler = &static_handler;
 	static_handler.func = wrapper;
-	static_handler.destroy = (BctbxLogHandlerDestroyFunc)bctbx_logv_out_destroy;
-	static_handler.user_info = (void*)bctbx_logv_out;
+	static_handler.destroy = (BctbxLogHandlerDestroyFunc)bctbx_handler_uninit;
+	static_handler.user_info = (void *)bctbx_logv_out;
 	bctbx_add_log_handler(&static_handler);
 }
 
-static bctbx_logger_t* bctbx_get_logger(void) {
+static bctbx_logger_t *bctbx_get_logger(void) {
 	if (main_logger.default_log_domain == NULL) {
 		main_logger.default_log_domain =
 		    bctbx_log_domain_new(NULL, BCTBX_LOG_WARNING | BCTBX_LOG_ERROR | BCTBX_LOG_FATAL);
@@ -164,13 +169,13 @@ void bctbx_init_logger(BCTBX_UNUSED(bool_t create)) {
 void bctbx_log_handlers_free(void) {
 	bctbx_list_t *handlers = bctbx_list_first_elem(bctbx_get_logger()->logv_outs);
 	while (handlers) {
-		bctbx_log_handler_t* handler = (bctbx_log_handler_t*)handlers->data;
+		bctbx_log_handler_t *handler = (bctbx_log_handler_t *)handlers->data;
 		handler->destroy(handler);
 		handlers = handlers->next;
 	}
 }
 
-void bctbx_uninit_logger(void){
+void bctbx_uninit_logger(void) {
 	/* Calling bctbx_uninit_logger() from a component is dangerous as it will reset the default logger.
 	 * it is safer that this function does nothing.*/
 #if 0
@@ -186,31 +191,31 @@ void bctbx_uninit_logger(void){
 #endif
 }
 
-bctbx_log_handler_t* bctbx_create_log_handler(BctbxLogHandlerFunc func, BctbxLogHandlerDestroyFunc destroy, void* user_info) {
-	bctbx_log_handler_t* handler = (bctbx_log_handler_t*)bctbx_malloc0(sizeof(bctbx_log_handler_t));
+bctbx_log_handler_t *
+bctbx_create_log_handler(BctbxLogHandlerFunc func, BctbxLogHandlerDestroyFunc destroy, void *user_info) {
+	bctbx_log_handler_t *handler = (bctbx_log_handler_t *)bctbx_malloc0(sizeof(bctbx_log_handler_t));
 	handler->func = func;
 	handler->destroy = destroy;
 	handler->user_info = user_info;
 	return handler;
 }
 
-void bctbx_log_handler_set_user_data(bctbx_log_handler_t* log_handler, void* user_data) {
+void bctbx_log_handler_set_user_data(bctbx_log_handler_t *log_handler, void *user_data) {
 	log_handler->user_info = user_data;
 }
-void *bctbx_log_handler_get_user_data(const bctbx_log_handler_t* log_handler) {
+void *bctbx_log_handler_get_user_data(const bctbx_log_handler_t *log_handler) {
 	return log_handler->user_info;
 }
 
-void bctbx_log_handler_set_domain(bctbx_log_handler_t * log_handler, const char *domain) {
+void bctbx_log_handler_set_domain(bctbx_log_handler_t *log_handler, const char *domain) {
 	if (log_handler->domain) bctbx_free(log_handler->domain);
 	if (domain) {
 		log_handler->domain = bctbx_strdup(domain);
 	} else {
-		log_handler->domain = NULL ;
+		log_handler->domain = NULL;
 	}
-	
 }
-bctbx_log_handler_t* bctbx_create_file_log_handler(uint64_t max_size, const char* path, const char* name) {
+bctbx_log_handler_t *bctbx_create_file_log_handler(uint64_t max_size, const char *path, const char *name) {
 	bctbx_log_handler_t *handler = NULL;
 	bctbx_file_log_handler_t *filehandler = NULL;
 	char *full_name = bctbx_strdup_printf("%s/%s", path, name);
@@ -235,7 +240,7 @@ bctbx_log_handler_t* bctbx_create_file_log_handler(uint64_t max_size, const char
 
 	handler = bctbx_new0(bctbx_log_handler_t, 1);
 	handler->func = bctbx_logv_file;
-	handler->destroy = bctbx_logv_file_destroy;
+	handler->destroy = bctbx_handler_logv_file_destroy;
 	handler->user_info = filehandler;
 
 end:
@@ -252,79 +257,78 @@ void bctbx_file_log_handler_reopen(bctbx_log_handler_t *file_log_handler) {
 }
 
 /**
-*@param func: your logging function, compatible with the BctoolboxLogFunc prototype.
-*
-**/
-void bctbx_add_log_handler(bctbx_log_handler_t* handler){
+ *@param func: your logging function, compatible with the BctoolboxLogFunc prototype.
+ *
+ **/
+void bctbx_add_log_handler(bctbx_log_handler_t *handler) {
 	bctbx_logger_t *logger = bctbx_get_logger();
 	if (handler && !bctbx_list_find(logger->logv_outs, handler))
-		logger->logv_outs = bctbx_list_append(logger->logv_outs, (void*)handler);
+		logger->logv_outs = bctbx_list_append(logger->logv_outs, (void *)handler);
 	/*else, already in*/
 }
 
-void bctbx_remove_log_handler(bctbx_log_handler_t* handler){
+void bctbx_remove_log_handler(bctbx_log_handler_t *handler) {
 	bctbx_logger_t *logger = bctbx_get_logger();
-	logger->logv_outs = bctbx_list_remove(logger->logv_outs,  handler);
+	logger->logv_outs = bctbx_list_remove(logger->logv_outs, handler);
 	handler->destroy(handler);
 	return;
 }
 
-
-void bctbx_set_log_handler(BctbxLogFunc func){
-	bctbx_set_log_handler_for_domain(func,NULL);
+void bctbx_set_log_handler(BctbxLogFunc func) {
+	bctbx_set_log_handler_for_domain(func, NULL);
 }
 
-void bctbx_set_log_handler_for_domain(BctbxLogFunc func, const char* domain) {
-	bctbx_log_handler_t* h = bctbx_get_logger()->default_handler;
+void bctbx_set_log_handler_for_domain(BctbxLogFunc func, const char *domain) {
+	bctbx_log_handler_t *h = bctbx_get_logger()->default_handler;
 
 	if (h == NULL) {
 		initialize_default_handler();
 		h = bctbx_get_logger()->default_handler;
 	}
 
-	h->user_info = (void*)func;
+	h->user_info = (void *)func;
 	bctbx_log_handler_set_domain(h, domain);
 }
 
-void bctbx_set_log_file(FILE* f){
-	static bctbx_file_log_handler_t filehandler;
-	static bctbx_log_handler_t handler;
-	handler.func=bctbx_logv_file;
-	handler.destroy=(BctbxLogHandlerDestroyFunc)bctbx_logv_file_destroy;
+void bctbx_set_log_file(FILE *f) {
+	static bctbx_file_log_handler_t filehandler = {0};
+	static bctbx_log_handler_t handler = {0};
+	handler.func = bctbx_logv_file;
+	handler.destroy = (BctbxLogHandlerDestroyFunc)bctbx_handler_logv_file_uninit;
 	filehandler.max_size = -1;
 	filehandler.file = f;
-	handler.user_info=(void*) &filehandler;
+	handler.user_info = (void *)&filehandler;
 	bctbx_add_log_handler(&handler);
 }
 
-bctbx_list_t* bctbx_get_log_handlers(void){
+bctbx_list_t *bctbx_get_log_handlers(void) {
 	return bctbx_get_logger()->logv_outs;
 }
 
-static BctoolboxLogDomain * get_log_domain(const char *domain){
+static BctoolboxLogDomain *get_log_domain(const char *domain) {
 	bctbx_list_t *it;
 	bctbx_logger_t *logger = bctbx_get_logger();
 
 	if (domain == NULL) return logger->default_log_domain;
 	for (it = logger->log_domains; it != NULL; it = bctbx_list_next(it)) {
-		BctoolboxLogDomain *ld = (BctoolboxLogDomain*)bctbx_list_get_data(it);
-		if (ld->domain && strcmp(ld->domain, domain) == 0 ){
+		BctoolboxLogDomain *ld = (BctoolboxLogDomain *)bctbx_list_get_data(it);
+		if (ld->domain && strcmp(ld->domain, domain) == 0) {
 			return ld;
 		}
 	}
 	return NULL;
 }
 
-static BctoolboxLogDomain *get_log_domain_rw(const char *domain){
+static BctoolboxLogDomain *get_log_domain_rw(const char *domain) {
 	BctoolboxLogDomain *ret;
 	bctbx_logger_t *logger = bctbx_get_logger();
-	
+
 	ret = get_log_domain(domain);
 	if (ret) return ret;
 	/*it does not exist, hence create it by taking the mutex*/
 	bctbx_mutex_lock(&logger->domains_mutex);
 	ret = get_log_domain(domain);
-	if (!ret){
+	if (!ret) {
 		ret = bctbx_log_domain_new(domain, logger->default_log_domain->logmask);
 		logger->log_domains = bctbx_list_prepend(logger->log_domains, ret);
 	}
@@ -333,34 +337,37 @@ static BctoolboxLogDomain *get_log_domain_rw(const char *domain){
 }
 
 /**
-* @ param levelmask a mask of BCTBX_DEBUG, BCTBX_MESSAGE, BCTBX_WARNING, BCTBX_ERROR
-* BCTBX_FATAL .
-**/
-void bctbx_set_log_level_mask(const char *domain, int levelmask){
+ * @ param levelmask a mask of BCTBX_DEBUG, BCTBX_MESSAGE, BCTBX_WARNING, BCTBX_ERROR
+ * BCTBX_FATAL .
+ **/
+void bctbx_set_log_level_mask(const char *domain, int levelmask) {
 	get_log_domain_rw(domain)->logmask = levelmask;
 }
 
-static unsigned int level_to_mask(BctbxLogLevel level){
+static unsigned int level_to_mask(BctbxLogLevel level) {
 	unsigned int levelmask = BCTBX_LOG_FATAL;
-	if (level<=BCTBX_LOG_ERROR){
+	if (level <= BCTBX_LOG_ERROR) {
 		levelmask |= BCTBX_LOG_ERROR;
 	}
-	if (level<=BCTBX_LOG_WARNING){
+	if (level <= BCTBX_LOG_WARNING) {
 		levelmask |= BCTBX_LOG_WARNING;
 	}
-	if (level<=BCTBX_LOG_MESSAGE){
+	if (level <= BCTBX_LOG_MESSAGE) {
 		levelmask |= BCTBX_LOG_MESSAGE;
 	}
-	if (level<=BCTBX_LOG_TRACE)	{
+	if (level <= BCTBX_LOG_TRACE) {
 		levelmask |= BCTBX_LOG_TRACE;
 	}
-	if (level<=BCTBX_LOG_DEBUG){
+	if (level <= BCTBX_LOG_DEBUG) {
 		levelmask |= BCTBX_LOG_DEBUG;
 	}
 	return levelmask;
 }
 
-void bctbx_set_log_level(const char *domain, BctbxLogLevel level){
+/**
+ * Set log level
+ **/
+void bctbx_set_log_level(const char *domain, BctbxLogLevel level) {
 	bctbx_set_log_level_mask(domain, level_to_mask(level));
 }
 
@@ -370,11 +377,11 @@ unsigned int bctbx_get_log_level_mask(const char *domain) {
 	return ld->logmask;
 }
 
-int bctbx_log_level_enabled(const char *domain, BctbxLogLevel level){
+int bctbx_log_level_enabled(const char *domain, BctbxLogLevel level) {
 	unsigned int logmask = 0;
 	BctoolboxLogDomain *ld = get_log_domain(domain);
 	if (!ld) ld = bctbx_get_logger()->default_log_domain;
-	
+
 #ifdef THREAD_LOG_LEVEL_ENABLED
 	if (ld->thread_level_set) logmask = bctbx_log_domain_get_thread_log_level_mask(ld);
 #endif
@@ -393,37 +400,32 @@ void bctbx_set_log_thread_id(unsigned long thread_id) {
 	logger->log_thread_id = thread_id;
 }
 
-char * bctbx_strdup_vprintf(const char *fmt, va_list ap)
-{
-/* Guess we need no more than 100 bytes. */
+char *bctbx_strdup_vprintf(const char *fmt, va_list ap) {
+	/* Guess we need no more than 100 bytes. */
 	int n, size = 200;
-	char *p,*np;
+	char *p, *np;
 #ifndef _WIN32
-	va_list cap;/*copy of our argument list: a va_list cannot be re-used (SIGSEGV on linux 64 bits)*/
+	va_list cap; /*copy of our argument list: a va_list cannot be re-used (SIGSEGV on linux 64 bits)*/
 #endif
-	if ((p = (char *) bctbx_malloc (size)) == NULL)
-		return NULL;
-	while (1){
+	if ((p = (char *)bctbx_malloc(size)) == NULL) return NULL;
+	while (1) {
 /* Try to print in the allocated space. */
 #ifndef _WIN32
-		va_copy(cap,ap);
-		n = vsnprintf (p, size, fmt, cap);
+		va_copy(cap, ap);
+		n = vsnprintf(p, size, fmt, cap);
 		va_end(cap);
 #else
 		/*this works on 32 bits, luckily*/
-		n = vsnprintf (p, size, fmt, ap);
+		n = vsnprintf(p, size, fmt, ap);
 #endif
 		/* If that worked, return the string. */
-		if (n > -1 && n < size)
-			return p;
-//printf("Reallocing space.\n");
+		if (n > -1 && n < size) return p;
+		// printf("Reallocing space.\n");
 		/* Else try again with more space. */
-		if (n > -1)	/* glibc 2.1 */
-			size = n + 1;	/* precisely what is needed */
-		else		/* glibc 2.0 */
-			size *= 2;	/* twice the old size */
-		if ((np = (char *) bctbx_realloc (p, size)) == NULL)
-		{
+		if (n > -1)                     /* glibc 2.1 */
+			size = n + 1;               /* precisely what is needed */
+		else /* glibc 2.0 */ size *= 2; /* twice the old size */
+		if ((np = (char *)bctbx_realloc(p, size)) == NULL) {
 			free(p);
 			return NULL;
 		} else {
@@ -432,27 +434,27 @@ char * bctbx_strdup_vprintf(const char *fmt, va_list ap)
 	}
 }
 
-char *bctbx_strdup_printf(const char *fmt,...){
+char *bctbx_strdup_printf(const char *fmt, ...) {
 	char *ret;
 	va_list args;
-	va_start (args, fmt);
-	ret=bctbx_strdup_vprintf(fmt, args);
-	va_end (args);
+	va_start(args, fmt);
+	ret = bctbx_strdup_vprintf(fmt, args);
+	va_end(args);
 	return ret;
 }
 
-char * bctbx_strcat_vprintf(char* dst, const char *fmt, va_list ap){
+char *bctbx_strcat_vprintf(char *dst, const char *fmt, va_list ap) {
 	char *ret;
 	size_t dstlen, retlen;
 
-	ret=bctbx_strdup_vprintf(fmt, ap);
+	ret = bctbx_strdup_vprintf(fmt, ap);
 	if (!dst) return ret;
 
 	dstlen = strlen(dst);
 	retlen = strlen(ret);
 
-	if ((dst = bctbx_realloc(dst, dstlen+retlen+1)) != NULL){
-		strcat(dst,ret);
+	if ((dst = bctbx_realloc(dst, dstlen + retlen + 1)) != NULL) {
+		strcat(dst, ret);
 		bctbx_free(ret);
 		return dst;
 	} else {
@@ -461,16 +463,16 @@ char * bctbx_strcat_vprintf(char* dst, const char *fmt, va_list ap){
 	}
 }
 
-char *bctbx_strcat_printf(char* dst, const char *fmt,...){
+char *bctbx_strcat_printf(char *dst, const char *fmt, ...) {
 	char *ret;
 	va_list args;
-	va_start (args, fmt);
-	ret=bctbx_strcat_vprintf(dst, fmt, args);
-	va_end (args);
+	va_start(args, fmt);
+	ret = bctbx_strcat_vprintf(dst, fmt, args);
+	va_end(args);
 	return ret;
 }
 
-#if	!defined(BCTBX_WINDOWS_UWP) && (defined(_WIN32) || defined(_WIN32_WCE))
+#if !defined(BCTBX_WINDOWS_UWP) && (defined(_WIN32) || defined(_WIN32_WCE))
 #define ENDLINE "\r\n"
 #else
 #define ENDLINE "\n"
@@ -487,9 +489,9 @@ void _bctbx_logv_flush(int dummy, ...) {
 	bctbx_list_t *msglist;
 	va_list empty_va_list;
 	va_start(empty_va_list, dummy);
-	
+
 	bctbx_logger_t *logger = bctbx_get_logger();
-	
+
 	bctbx_mutex_lock(&logger->log_stored_messages_mutex);
 	msglist = logger->log_stored_messages_list;
 	logger->log_stored_messages_list = NULL;
@@ -499,8 +501,8 @@ void _bctbx_logv_flush(int dummy, ...) {
 		bctbx_list_t *handlers = bctbx_list_first_elem(logger->logv_outs);
 #ifdef _WIN32
 		while (handlers) {
-			bctbx_log_handler_t* handler = (bctbx_log_handler_t*)handlers->data;
-			if(handler) {
+			bctbx_log_handler_t *handler = (bctbx_log_handler_t *)handlers->data;
+			if (handler) {
 				va_list cap;
 				va_copy(cap, empty_va_list);
 				handler->func(handler->user_info, l->domain, l->level, l->msg, cap);
@@ -509,10 +511,10 @@ void _bctbx_logv_flush(int dummy, ...) {
 			handlers = handlers->next;
 		}
 #else
-		
+
 		while (handlers) {
-			bctbx_log_handler_t* handler = (bctbx_log_handler_t*)handlers->data;
-			if(handler) {
+			bctbx_log_handler_t *handler = (bctbx_log_handler_t *)handlers->data;
+			if (handler) {
 				va_list cap;
 				va_copy(cap, empty_va_list);
 				handler->func(handler->user_info, l->domain, l->level, l->msg, cap);
@@ -520,7 +522,7 @@ void _bctbx_logv_flush(int dummy, ...) {
 			}
 			handlers = handlers->next;
 		}
-		
+
 #endif
 		if (l->domain) bctbx_free(l->domain);
 		bctbx_free(l->msg);
@@ -536,13 +538,13 @@ void bctbx_logv_flush(void) {
 
 void bctbx_logv(const char *domain, BctbxLogLevel level, const char *fmt, va_list args) {
 	bctbx_logger_t *logger = bctbx_get_logger();
-	
+
 	if ((logger->logv_outs != NULL) && bctbx_log_level_enabled(domain, level)) {
 		if (logger->log_thread_id == 0) {
 			bctbx_list_t *handlers = bctbx_list_first_elem(logger->logv_outs);
 			while (handlers) {
-				bctbx_log_handler_t* handler = (bctbx_log_handler_t*)handlers->data;
-				if(handler && (!handler->domain || !domain || strcmp(handler->domain,domain)==0)) {
+				bctbx_log_handler_t *handler = (bctbx_log_handler_t *)handlers->data;
+				if (handler && (!handler->domain || !domain || strcmp(handler->domain, domain) == 0)) {
 					va_list tmp;
 					va_copy(tmp, args);
 					handler->func(handler->user_info, domain, level, fmt, tmp);
@@ -555,8 +557,8 @@ void bctbx_logv(const char *domain, BctbxLogLevel level, const char *fmt, va_lis
 			bctbx_logv_flush();
 			handlers = bctbx_list_first_elem(logger->logv_outs);
 			while (handlers) {
-				bctbx_log_handler_t* handler = (bctbx_log_handler_t*)handlers->data;
-				if(handler && (!handler->domain || !domain || strcmp(handler->domain,domain)==0)) {
+				bctbx_log_handler_t *handler = (bctbx_log_handler_t *)handlers->data;
+				if (handler && (!handler->domain || !domain || strcmp(handler->domain, domain) == 0)) {
 					va_list tmp;
 					va_copy(tmp, args);
 					handler->func(handler->user_info, domain, level, fmt, tmp);
@@ -578,7 +580,7 @@ void bctbx_logv(const char *domain, BctbxLogLevel level, const char *fmt, va_lis
 	if (level == BCTBX_LOG_FATAL) {
 		bctbx_logv_flush();
 #ifdef __ANDROID__
-        //Act as a flush + abort
+		// Act as a flush + abort
 		__android_log_assert(NULL, NULL, "%s", "Aborting");
 #else
 		abort();
@@ -586,13 +588,14 @@ void bctbx_logv(const char *domain, BctbxLogLevel level, const char *fmt, va_lis
 	}
 #endif
 }
-void bctbx_logv_out( const char *domain, BctbxLogLevel lev, const char *fmt, va_list args){
+void bctbx_logv_out(const char *domain, BctbxLogLevel lev, const char *fmt, va_list args) {
 	bctbx_logv_out_cb(NULL, domain, lev, fmt, args);
 }
 /*This function does the default formatting and output to file*/
-void bctbx_logv_out_cb(BCTBX_UNUSED(void* user_info), const char *domain, BctbxLogLevel lev, const char *fmt, va_list args){
-	const char *lname="undef";
-	char *msg;
+void bctbx_logv_out_cb(
+    BCTBX_UNUSED(void *user_info), const char *domain, BctbxLogLevel lev, const char *fmt, va_list args) {
+	const char *lname = "undef";
+	char *msg, *tags = NULL;
 	struct timeval tp;
 	struct tm *lt;
 #ifndef _WIN32
@@ -600,71 +603,71 @@ void bctbx_logv_out_cb(BCTBX_UNUSED(void* user_info), const char *domain, BctbxL
 #endif
 	time_t tt;
 	FILE *std = stdout;
-	bctbx_gettimeofday(&tp,NULL);
+	bctbx_gettimeofday(&tp, NULL);
 	tt = (time_t)tp.tv_sec;
 
 #ifdef _WIN32
 	lt = localtime(&tt);
 #else
-	lt = localtime_r(&tt,&tmbuf);
+	lt = localtime_r(&tt, &tmbuf);
 #endif
 
-	switch(lev){
+	switch (lev) {
 		case BCTBX_LOG_DEBUG:
 			lname = "debug";
-		break;
+			break;
 		case BCTBX_LOG_MESSAGE:
 			lname = "message";
-		break;
+			break;
 		case BCTBX_LOG_WARNING:
 			lname = "warning";
-		break;
+			break;
 		case BCTBX_LOG_ERROR:
 			lname = "error";
 			std = stderr;
-		break;
+			break;
 		case BCTBX_LOG_FATAL:
 			lname = "fatal";
 			std = stderr;
-		break;
+			break;
 		default:
 			lname = "badlevel";
 	}
 
-	msg=bctbx_strdup_vprintf(fmt,args);
+	msg = bctbx_strdup_vprintf(fmt, args);
 #if defined(_MSC_VER) && !defined(_WIN32_WCE)
 #ifndef _UNICODE
 	OutputDebugStringA(msg);
 	OutputDebugStringA("\r\n");
 #else
 	{
-		size_t len=strlen(msg);
-		wchar_t *tmp=(wchar_t*)bctbx_malloc0((len+1)*sizeof(wchar_t));
-		mbstowcs(tmp,msg,len);
+		size_t len = strlen(msg);
+		wchar_t *tmp = (wchar_t *)bctbx_malloc0((len + 1) * sizeof(wchar_t));
+		mbstowcs(tmp, msg, len);
 		OutputDebugStringW(tmp);
 		OutputDebugStringW(L"\r\n");
 		bctbx_free(tmp);
 	}
 #endif
 #endif
-	fprintf(std,"%i-%.2i-%.2i %.2i:%.2i:%.2i:%.3i %s-%s-%s" ENDLINE
-			,1900+lt->tm_year,1+lt->tm_mon,lt->tm_mday,lt->tm_hour,lt->tm_min,lt->tm_sec
-		,(int)(tp.tv_usec/1000), (domain?domain:"bctoolbox"), lname, msg);
+	tags = format_tags();
+	fprintf(std, "%i-%.2i-%.2i %.2i:%.2i:%.2i:%.3i %s-%s-%s %s" ENDLINE, 1900 + lt->tm_year, 1 + lt->tm_mon,
+	        lt->tm_mday, lt->tm_hour, lt->tm_min, lt->tm_sec, (int)(tp.tv_usec / 1000), (domain ? domain : "bctoolbox"),
+	        lname, tags ? tags : "", msg);
 	fflush(std);
 	bctbx_free(msg);
+	if (tags) bctbx_free(tags);
 }
 
-void bctbx_logv_out_destroy(bctbx_log_handler_t* handler) {
-	handler->user_info=NULL;
+static void bctbx_handler_uninit(bctbx_log_handler_t *handler) {
+	handler->user_info = NULL;
 }
 
 static int _try_open_log_collection_file(bctbx_file_log_handler_t *filehandler) {
 	struct stat statbuf;
 	char *log_filename;
 
-	log_filename = bctbx_strdup_printf("%s/%s",
-		filehandler->path,
-		filehandler->name);
+	log_filename = bctbx_strdup_printf("%s/%s", filehandler->path, filehandler->name);
 	filehandler->file = fopen(log_filename, "a");
 	bctbx_free(log_filename);
 	if (filehandler->file == NULL) return -1;
@@ -684,41 +687,26 @@ static void _rotate_log_collection_files(bctbx_file_log_handler_t *filehandler)
 	char *log_filename2;
 	int n = 1;
 
-	log_filename = bctbx_strdup_printf("%s/%s_1",
-		filehandler->path,
-		filehandler->name);
-	while(access(log_filename, F_OK) != -1) {
+	log_filename = bctbx_strdup_printf("%s/%s_1", filehandler->path, filehandler->name);
+	while (access(log_filename, F_OK) != -1) {
 		// file exists
 		n++;
 		bctbx_free(log_filename);
-		log_filename = bctbx_strdup_printf("%s/%s_%d",
-		filehandler->path,
-		filehandler->name,
-		n);
+		log_filename = bctbx_strdup_printf("%s/%s_%d", filehandler->path, filehandler->name, n);
 	}
-	
-	while(n > 1) {
+
+	while (n > 1) {
 		bctbx_free(log_filename);
-		log_filename = bctbx_strdup_printf("%s/%s_%d",
-		filehandler->path,
-		filehandler->name,
-		n-1);
-		log_filename2 = bctbx_strdup_printf("%s/%s_%d",
-		filehandler->path,
-		filehandler->name,
-		n);
+		log_filename = bctbx_strdup_printf("%s/%s_%d", filehandler->path, filehandler->name, n - 1);
+		log_filename2 = bctbx_strdup_printf("%s/%s_%d", filehandler->path, filehandler->name, n);
 
 		n--;
 		rename(log_filename, log_filename2);
 		bctbx_free(log_filename2);
 	}
 	bctbx_free(log_filename);
-	log_filename = bctbx_strdup_printf("%s/%s",
-		filehandler->path,
-		filehandler->name);
-	log_filename2 = bctbx_strdup_printf("%s/%s_1",
-		filehandler->path,
-		filehandler->name);
+	log_filename = bctbx_strdup_printf("%s/%s", filehandler->path, filehandler->name);
+	log_filename2 = bctbx_strdup_printf("%s/%s_1", filehandler->path, filehandler->name);
 	rename(log_filename, log_filename2);
 	bctbx_free(log_filename);
 	bctbx_free(log_filename2);
@@ -739,9 +727,26 @@ static void _close_log_collection_file(bctbx_file_log_handler_t *filehandler) {
 	}
 }
 
-void bctbx_logv_file(void* user_info, const char *domain, BctbxLogLevel lev, const char *fmt, va_list args){
-	const char *lname="undef";
+static char *format_tags(void) {
+	const bctbx_list_t *tags = bctbx_get_log_tags();
+	const bctbx_list_t *elem;
+	char *tags_str = NULL;
+	for (elem = tags; elem != NULL; elem = elem->next) {
+		const char *tag = (const char *)elem->data;
+		if (tags_str == NULL) tags_str = bctbx_strdup_printf("[%s]", tag);
+		else {
+			char *new_tags_str = bctbx_strdup_printf("%s[%s]", tags_str, tag);
+			bctbx_free(tags_str);
+			tags_str = new_tags_str;
+		}
+	}
+	return tags_str;
+}
+
+void bctbx_logv_file(void *user_info, const char *domain, BctbxLogLevel lev, const char *fmt, va_list args) {
+	const char *lname = "undef";
 	char *msg = NULL;
+	char *tags = NULL;
 	struct timeval tp;
 	struct tm *lt;
 #ifndef _WIN32
@@ -749,62 +754,64 @@ void bctbx_logv_file(void* user_info, const char *domain, BctbxLogLevel lev, con
 #endif
 	time_t tt;
 	int ret = -1;
-	bctbx_file_log_handler_t *filehandler = (bctbx_file_log_handler_t *) user_info;
+	bctbx_file_log_handler_t *filehandler = (bctbx_file_log_handler_t *)user_info;
 	bctbx_logger_t *logger = bctbx_get_logger();
-	
+
 	bctbx_mutex_lock(&logger->log_mutex);
 	FILE *f = filehandler ? filehandler->file : stdout;
-	bctbx_gettimeofday(&tp,NULL);
+	bctbx_gettimeofday(&tp, NULL);
 	tt = (time_t)tp.tv_sec;
 
 #ifdef _WIN32
 	lt = localtime(&tt);
 #else
-	lt = localtime_r(&tt,&tmbuf);
+	lt = localtime_r(&tt, &tmbuf);
 #endif
 
-	if(!f) goto end;
+	if (!f) goto end;
 
-	switch(lev){
+	switch (lev) {
 		case BCTBX_LOG_DEBUG:
 			lname = "debug";
-		break;
+			break;
 		case BCTBX_LOG_MESSAGE:
 			lname = "message";
-		break;
+			break;
 		case BCTBX_LOG_WARNING:
 			lname = "warning";
-		break;
+			break;
 		case BCTBX_LOG_ERROR:
 			lname = "error";
-		break;
+			break;
 		case BCTBX_LOG_FATAL:
 			lname = "fatal";
-		break;
+			break;
 		default:
 			lname = "badlevel";
 	}
 
-	msg=bctbx_strdup_vprintf(fmt,args);
+	msg = bctbx_strdup_vprintf(fmt, args);
 #if defined(_MSC_VER) && !defined(_WIN32_WCE)
 #ifndef _UNICODE
 	OutputDebugStringA(msg);
 	OutputDebugStringA("\r\n");
 #else
 	{
-		size_t len=strlen(msg);
-		wchar_t *tmp=(wchar_t*)bctbx_malloc0((len+1)*sizeof(wchar_t));
-		mbstowcs(tmp,msg,len);
+		size_t len = strlen(msg);
+		wchar_t *tmp = (wchar_t *)bctbx_malloc0((len + 1) * sizeof(wchar_t));
+		mbstowcs(tmp, msg, len);
 		OutputDebugStringW(tmp);
 		OutputDebugStringW(L"\r\n");
 		bctbx_free(tmp);
 	}
 #endif
 #endif
-	ret = fprintf(f,"%i-%.2i-%.2i %.2i:%.2i:%.2i:%.3i %s-%s-%s" ENDLINE
-			,1900+lt->tm_year,1+lt->tm_mon,lt->tm_mday,lt->tm_hour,lt->tm_min,lt->tm_sec
-		,(int)(tp.tv_usec/1000), (domain?domain:"bctoolbox"), lname, msg);
+	tags = format_tags();
+	ret = fprintf(f, "%i-%.2i-%.2i %.2i:%.2i:%.2i:%.3i %s-%s-%s %s" ENDLINE, 1900 + lt->tm_year, 1 + lt->tm_mon,
+	              lt->tm_mday, lt->tm_hour, lt->tm_min, lt->tm_sec, (int)(tp.tv_usec / 1000),
+	              (domain ? domain : "bctoolbox"), lname, tags ? tags : "", msg);
 	fflush(f);
+	if (tags) bctbx_free(tags);
 
 	/* reopen the log file when either the size limit has been exceeded, or reopen has been required
 	   by the user. Reopening a log file that has reached the size limit automatically trigger log rotation
@@ -827,22 +834,30 @@ end:
 	if (msg) bctbx_free(msg);
 }
 
-void bctbx_logv_file_destroy(bctbx_log_handler_t* handler) {
-	bctbx_file_log_handler_t *filehandler = (bctbx_file_log_handler_t *) handler->user_info;
+static void bctbx_handler_logv_file_uninit(bctbx_log_handler_t *handler) {
+	bctbx_file_log_handler_t *filehandler = (bctbx_file_log_handler_t *)handler->user_info;
 	fclose(filehandler->file);
 	bctbx_free(filehandler->path);
 	bctbx_free(filehandler->name);
-	bctbx_logv_out_destroy(handler);
+	bctbx_handler_uninit(handler);
+}
+
+static void bctbx_handler_logv_file_destroy(bctbx_log_handler_t *handler) {
+	bctbx_file_log_handler_t *filehandler = (bctbx_file_log_handler_t *)handler->user_info;
+	bctbx_handler_logv_file_uninit(handler);
+	bctbx_free(filehandler);
+	bctbx_handler_uninit(handler);
+	bctbx_free(handler);
 }
 
 #ifndef _MSC_VER
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wunused-parameter"
 #endif // _MSC_VER
-void bctbx_set_thread_log_level(const char *domain, BctbxLogLevel level){
+void bctbx_set_thread_log_level(const char *domain, BctbxLogLevel level) {
 #ifdef THREAD_LOG_LEVEL_ENABLED
-	BctoolboxLogDomain * ld = get_log_domain(domain);
-	unsigned int *specific = (unsigned int*)pthread_getspecific(ld->thread_level_key);
+	BctoolboxLogDomain *ld = get_log_domain(domain);
+	unsigned int *specific = (unsigned int *)pthread_getspecific(ld->thread_level_key);
 	if (!specific) specific = bctbx_new0(unsigned int, 1);
 	*specific = level_to_mask(level);
 	pthread_setspecific(ld->thread_level_key, specific);
@@ -857,10 +872,10 @@ void bctbx_set_thread_log_level(const char *domain, BctbxLogLevel level){
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wunused-parameter"
 #endif // _MSC_VER
-void bctbx_clear_thread_log_level(const char *domain){
+void bctbx_clear_thread_log_level(const char *domain) {
 #ifdef THREAD_LOG_LEVEL_ENABLED
-	BctoolboxLogDomain * ld = get_log_domain(domain);
-	unsigned int *specific = (unsigned int*)pthread_getspecific(ld->thread_level_key);
+	BctoolboxLogDomain *ld = get_log_domain(domain);
+	unsigned int *specific = (unsigned int *)pthread_getspecific(ld->thread_level_key);
 	if (specific) *specific = 0;
 #endif
 }
@@ -878,7 +893,7 @@ static slog2_buffer_t slog2_buffer_handle[2];
 void bctbx_qnx_log_handler(const char *domain, BctbxLogLevel lev, const char *fmt, va_list args) {
 	uint8_t severity = SLOG2_DEBUG1;
 	uint8_t buffer_idx = 1;
-	char* msg;
+	char *msg;
 
 	if (slog2_registered != TRUE) {
 		slog2_buffer_config.buffer_set_name = domain;
@@ -896,27 +911,27 @@ void bctbx_qnx_log_handler(const char *domain, BctbxLogLevel lev, const char *fm
 		}
 	}
 
-	switch(lev){
+	switch (lev) {
 		case BCTBX_LOG_DEBUG:
 			severity = SLOG2_DEBUG1;
-		break;
+			break;
 		case BCTBX_LOG_MESSAGE:
 			severity = SLOG2_INFO;
-		break;
+			break;
 		case BCTBX_LOG_WARNING:
 			severity = SLOG2_WARNING;
-		break;
+			break;
 		case BCTBX_LOG_ERROR:
 			severity = SLOG2_ERROR;
-		break;
+			break;
 		case BCTBX_LOG_FATAL:
 			severity = SLOG2_CRITICAL;
-		break;
+			break;
 		default:
 			severity = SLOG2_CRITICAL;
 	}
 
-	msg = bctbx_strdup_vprintf(fmt,args);
+	msg = bctbx_strdup_vprintf(fmt, args);
 	slog2c(slog2_buffer_handle[buffer_idx], 0, severity, msg);
 }
 
