@@ -27,32 +27,29 @@
 #include "bctoolbox/regex.h"
 
 /*
-	This part is needed since CentOS7 have an old gcc compiler.
-	TODO: Remove this code when all supported platorms have gcc 4.9.0 or more 
+    This part is needed since CentOS7 have an old gcc compiler.
+    TODO: Remove this code when all supported platorms have gcc 4.9.0 or more
  */
-#if __cplusplus >= 201103L                             && \
-    (!defined(__GLIBCXX__) || (__cplusplus >= 201402L) || \
-        (defined(_GLIBCXX_REGEX_DFS_QUANTIFIERS_LIMIT) || \
-         defined(_GLIBCXX_REGEX_STATE_LIMIT)           || \
-             (defined(_GLIBCXX_RELEASE)                && \
-             _GLIBCXX_RELEASE > 4)))                   && \
-	!defined(__ANDROID__) || defined(_WIN32)
+#if __cplusplus >= 201103L &&                                                                                          \
+        (!defined(__GLIBCXX__) || (__cplusplus >= 201402L) ||                                                          \
+         (defined(_GLIBCXX_REGEX_DFS_QUANTIFIERS_LIMIT) || defined(_GLIBCXX_REGEX_STATE_LIMIT) ||                      \
+          (defined(_GLIBCXX_RELEASE) && _GLIBCXX_RELEASE > 4))) &&                                                     \
+        !defined(__ANDROID__) ||                                                                                       \
+    defined(_WIN32)
 #define HAVE_WORKING_REGEX 1
 #else
 #define HAVE_WORKING_REGEX 0
 #include <regex.h>
 #endif
 
-extern "C" bool_t bctbx_is_matching_regex_log(const char *entry, const char* regex, bool_t show_log){
+extern "C" bool_t bctbx_is_matching_regex_log(const char *entry, const char *regex, bool_t show_log) {
 #if HAVE_WORKING_REGEX
 	try {
 		std::regex entry_regex(regex, std::regex_constants::extended | std::regex_constants::nosubs);
 		std::cmatch m;
 		return std::regex_match(entry, m, entry_regex);
-	}
-	catch (const std::regex_error& e) {
-		if(show_log)
-			bctbx_error("Could not compile regex '%s': %s", regex, e.what());
+	} catch (const std::regex_error &e) {
+		if (show_log) bctbx_error("Could not compile regex '%s': %s", regex, e.what());
 		return FALSE;
 	}
 #else
@@ -60,8 +57,8 @@ extern "C" bool_t bctbx_is_matching_regex_log(const char *entry, const char* reg
 	char err_msg[256];
 	int res;
 	res = regcomp(&regex_pattern, regex, REG_EXTENDED | REG_NOSUB);
-	if(res != 0) {
-		if(show_log) {
+	if (res != 0) {
+		if (show_log) {
 			regerror(res, &regex_pattern, err_msg, sizeof(err_msg));
 			bctbx_error("Could not compile regex '%s': %s", regex, err_msg);
 		}
@@ -73,6 +70,6 @@ extern "C" bool_t bctbx_is_matching_regex_log(const char *entry, const char* reg
 #endif
 }
 
-extern "C" bool_t bctbx_is_matching_regex(const char *entry, const char* regex) {
+extern "C" bool_t bctbx_is_matching_regex(const char *entry, const char *regex) {
 	return bctbx_is_matching_regex_log(entry, regex, TRUE);
 }
