@@ -18,7 +18,7 @@
  */
 
 #include "bctoolbox/utils.hh"
-#include<sstream> 
+#include <sstream>
 
 using namespace std;
 
@@ -27,7 +27,7 @@ using namespace Windows::System;
 using namespace Windows::Foundation;
 #endif
 
-vector<string> bctoolbox::Utils::split (const string &str, const string &delimiter) {
+vector<string> bctoolbox::Utils::split(const string &str, const string &delimiter) {
 	vector<string> out;
 
 	size_t pos = 0, oldPos = 0;
@@ -38,7 +38,7 @@ vector<string> bctoolbox::Utils::split (const string &str, const string &delimit
 	return out;
 }
 
-string bctoolbox::Utils::fold (const string &str) {
+string bctoolbox::Utils::fold(const string &str) {
 	string output = str;
 	size_t crlf = 0;
 	size_t next_crlf = 0;
@@ -59,7 +59,7 @@ string bctoolbox::Utils::fold (const string &str) {
 	return output;
 }
 
-string bctoolbox::Utils::unfold (const string &str) {
+string bctoolbox::Utils::unfold(const string &str) {
 	string output = str;
 	const char *endline = "\r\n";
 	size_t crlf = output.find(endline);
@@ -82,12 +82,11 @@ string bctoolbox::Utils::unfold (const string &str) {
 	return output;
 }
 
-void bctoolbox::Utils::replace(string& source, const string& from, const string& to, const bool& recursive){
+void bctoolbox::Utils::replace(string &source, const string &from, const string &to, const bool recursive) {
 	size_t start_pos = 0;
-	while((start_pos = source.find(from, start_pos)) != string::npos) {
+	while ((start_pos = source.find(from, start_pos)) != string::npos) {
 		source.replace(start_pos, from.length(), to);
-		if(recursive)
-			start_pos += to.length();
+		if (recursive) start_pos += to.length();
 	}
 }
 
@@ -97,23 +96,37 @@ std::string bctoolbox::Utils::getMemoryReportAsString() {
 	// Use to convert bytes to MB
 	const int division = 1048576;
 	MEMORYSTATUSEX memoryStatus;
-	memoryStatus.dwLength = sizeof (memoryStatus);
-	GlobalMemoryStatusEx (&memoryStatus);
+	memoryStatus.dwLength = sizeof(memoryStatus);
+	GlobalMemoryStatusEx(&memoryStatus);
 	ossReport << "Memory stats (MB): Usage=" << memoryStatus.dwMemoryLoad
-				<< ", Total physical=" << memoryStatus.ullTotalPhys/division
-				<< ", Free physical=" << memoryStatus.ullAvailPhys/division
-				<< ", Total paging file=" << memoryStatus.ullTotalPageFile/division
-				<< ", Free paging file=" << memoryStatus.ullAvailPageFile/division
-				<< ", Total virtual=" << memoryStatus.ullTotalVirtual/division
-				<< ", Free virtual=" << memoryStatus.ullAvailVirtual/division
-				<< ", Free extended=" << memoryStatus.ullAvailExtendedVirtual/division;
+	          << ", Total physical=" << memoryStatus.ullTotalPhys / division
+	          << ", Free physical=" << memoryStatus.ullAvailPhys / division
+	          << ", Total paging file=" << memoryStatus.ullTotalPageFile / division
+	          << ", Free paging file=" << memoryStatus.ullAvailPageFile / division
+	          << ", Total virtual=" << memoryStatus.ullTotalVirtual / division
+	          << ", Free virtual=" << memoryStatus.ullAvailVirtual / division
+	          << ", Free extended=" << memoryStatus.ullAvailExtendedVirtual / division;
 #ifdef BCTBX_WINDOWS_UWP
-	ossReport << " | UWP App Memory (MB): Usage=" << MemoryManager::AppMemoryUsage/division
-				<< ", Usage limit=" << MemoryManager::AppMemoryUsageLimit/division
-				<< ", Usage level=" << (int)MemoryManager::AppMemoryUsageLevel
-				<< ", Expected usage limit=" << MemoryManager::ExpectedAppMemoryUsageLimit/division
-				<< ", Free=" << (long)( MemoryManager::AppMemoryUsageLimit - MemoryManager::AppMemoryUsage )/division;
+	ossReport << " | UWP App Memory (MB): Usage=" << MemoryManager::AppMemoryUsage / division
+	          << ", Usage limit=" << MemoryManager::AppMemoryUsageLimit / division
+	          << ", Usage level=" << (int)MemoryManager::AppMemoryUsageLevel
+	          << ", Expected usage limit=" << MemoryManager::ExpectedAppMemoryUsageLimit / division
+	          << ", Free=" << (long)(MemoryManager::AppMemoryUsageLimit - MemoryManager::AppMemoryUsage) / division;
 #endif
 #endif
 	return ossReport.str();
 }
+
+bool bctoolbox::Utils::isExecutableInstalled(const std::string &executable, const std::string &resource) {
+	auto pos = executable.find_last_of('/');
+	if (pos == std::string::npos) {
+		pos = executable.find_last_of('\\');
+	}
+
+	std::string path = executable.substr(0, pos + 1).append("../share/");
+	std::string name = executable.substr(pos + 1);
+
+	std::string check = path + name + "/" + resource;
+
+	return bctbx_file_exist(check.c_str()) == 0;
+}
