@@ -17,31 +17,31 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "bctoolbox_tester.h"
 #include "bctoolbox/param_string.h"
-
-
+#include "bctoolbox_tester.h"
 
 static void get_value_test(void) {
 	size_t result_len = 10;
-	char * result = bctbx_malloc(result_len);
-	
-	char * paramString = "";
+	char *result = bctbx_malloc(result_len);
+
+	char *paramString = "";
 	BC_ASSERT_FALSE(bctbx_param_string_get_value(paramString, "param", result, result_len));
-	
+
 	paramString = "param=true";
 	BC_ASSERT_TRUE(bctbx_param_string_get_value(paramString, "param", result, result_len));
 	BC_ASSERT_TRUE(strcmp(result, "true") == 0);
 	BC_ASSERT_FALSE(bctbx_param_string_get_value(paramString, "notparam", result, result_len));
-	
+
 	paramString = "test;param=true;test";
 	BC_ASSERT_TRUE(bctbx_param_string_get_value(paramString, "param", result, result_len));
 	BC_ASSERT_TRUE(strcmp(result, "true") == 0);
 	BC_ASSERT_FALSE(bctbx_param_string_get_value(paramString, "notparam", result, result_len));
+
+	bctbx_free(result);
 }
 
 static void get_bool_value_test(void) {
-	char * paramString = "";
+	char *paramString = "";
 	BC_ASSERT_FALSE(bctbx_param_string_get_bool_value(paramString, "param"));
 	paramString = "param=false";
 	BC_ASSERT_FALSE(bctbx_param_string_get_bool_value(paramString, "param"));
@@ -51,10 +51,9 @@ static void get_bool_value_test(void) {
 	BC_ASSERT_TRUE(bctbx_param_string_get_bool_value(paramString, "param"));
 }
 
-static test_t param_string_tests[] = {
-	TEST_NO_TAG("Get value", get_value_test),
-	TEST_NO_TAG("Get bool value", get_bool_value_test)
-};
+static test_t param_string_tests[] = {TEST_NO_TAG("Get value", get_value_test),
+                                      TEST_NO_TAG("Get bool value", get_bool_value_test)};
 
-test_suite_t param_string_test_suite = {"Param string", NULL, NULL, NULL, NULL,
-							   sizeof(param_string_tests) / sizeof(param_string_tests[0]), param_string_tests, 0};
+test_suite_t param_string_test_suite = {
+    "Param string",     NULL, NULL, NULL, NULL, sizeof(param_string_tests) / sizeof(param_string_tests[0]),
+    param_string_tests, 0};
\ No newline at end of file
